summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
authormirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-29 00:51:30 +0000
committermirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-29 00:51:30 +0000
commitd4bc96e84f87586da6a312a3c8eed3a12b3221d3 (patch)
tree7438b38ef3a416a4cdff5dd2627b79dcbb13c70b /chrome/common
parent2b9e7d0b2432d887f58212c0e29885ddf2386caa (diff)
downloadchromium_src-d4bc96e84f87586da6a312a3c8eed3a12b3221d3.zip
chromium_src-d4bc96e84f87586da6a312a3c8eed3a12b3221d3.tar.gz
chromium_src-d4bc96e84f87586da6a312a3c8eed3a12b3221d3.tar.bz2
Adjust json data and URL to information from server side on custom logo signal delivery.
BUG=56388 TEST=unit test for web_resource_service still works. Review URL: http://codereview.chromium.org/3523002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@60884 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/pref_names.cc7
-rw-r--r--chrome/common/pref_names.h3
2 files changed, 7 insertions, 3 deletions
diff --git a/chrome/common/pref_names.h b/chrome/common/pref_names.h
index 86e33aa..ea7c959 100644
--- a/chrome/common/pref_names.h
+++ b/chrome/common/pref_names.h
@@ -324,7 +324,8 @@ extern const char kNTPMostVisitedURLsBlacklist[];
extern const char kNTPMostVisitedPinnedURLs[];
extern const char kNTPWebResourceCache[];
extern const char kNTPWebResourceCacheUpdate[];
-extern const char kNTPWebResourceServer[];
+extern const char kNTPTipsResourceServer[];
+extern const char kNTPLogoResourceServer[];
extern const char kNTPShownSections[];
extern const char kNTPPrefVersion[];
extern const char kNTPCustomLogoStart[];
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index ae4b257..dcaa943 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -885,8 +885,11 @@ const char kNTPWebResourceCache[] = "ntp.web_resource_cache";
// Last time of update of web_resource_cache.
const char kNTPWebResourceCacheUpdate[] = "ntp.web_resource_cache_update";
-// Last server used to fill web_resource_cache.
-const char kNTPWebResourceServer[] = "ntp.web_resource_server";
+// Last server used to fill tips.
+const char kNTPTipsResourceServer[] = "ntp.tips_resource_server";
+
+// Last server used to fill logo_resource_cache.
+const char kNTPLogoResourceServer[] = "ntp.logo_resource_server";
// Which sections should be visible on the new tab page
// 1 - Show the most visited sites in a grid